Title: [168143] trunk/WebKitLibraries
Revision
168143
Author
bfulg...@apple.com
Date
2014-05-01 18:45:13 -0700 (Thu, 01 May 2014)

Log Message

Correct case of environment variables in auto-version.sh scripts
https://bugs.webkit.org/show_bug.cgi?id=132455

Reviewed by Dean Jackson.

Although we have historically used RC_PROJECTSOURCEVERSION in our scripts,
the actual environment variable is RC_ProjectSourceVersion. Old versions of
Cygwin converted this to all-caps by default, but this is no longer the case.
We need to use the proper case to avoid build failures.

* win/tools/scripts/auto-version.sh: Although we have historically coded
this as 'RC_PROJECTSOURCEVERSION', it is actually 'RC_ProjectSourceVersion'.

Modified Paths

Diff

Modified: trunk/WebKitLibraries/ChangeLog (168142 => 168143)


--- trunk/WebKitLibraries/ChangeLog	2014-05-02 01:40:13 UTC (rev 168142)
+++ trunk/WebKitLibraries/ChangeLog	2014-05-02 01:45:13 UTC (rev 168143)
@@ -1,3 +1,18 @@
+2014-05-01  Brent Fulgham  <bfulg...@apple.com>
+
+        Correct case of environment variables in auto-version.sh scripts
+        https://bugs.webkit.org/show_bug.cgi?id=132455
+
+        Reviewed by Dean Jackson.
+
+        Although we have historically used RC_PROJECTSOURCEVERSION in our scripts,
+        the actual environment variable is RC_ProjectSourceVersion. Old versions of
+        Cygwin converted this to all-caps by default, but this is no longer the case.
+        We need to use the proper case to avoid build failures.
+
+        * win/tools/scripts/auto-version.sh: Although we have historically coded
+        this as 'RC_PROJECTSOURCEVERSION', it is actually 'RC_ProjectSourceVersion'.
+
 2014-04-25  Dean Jackson  <d...@apple.com>
 
         Update WKSI for https://webkit.org/b/132195

Modified: trunk/WebKitLibraries/win/tools/scripts/auto-version.sh (168142 => 168143)


--- trunk/WebKitLibraries/win/tools/scripts/auto-version.sh	2014-05-02 01:40:13 UTC (rev 168142)
+++ trunk/WebKitLibraries/win/tools/scripts/auto-version.sh	2014-05-02 01:45:13 UTC (rev 168143)
@@ -44,9 +44,9 @@
 OUTPUT_FILE=$(cygpath -u "$1")/include/autoversion.h
 mkdir -p "$(dirname "$OUTPUT_FILE")"
 
 # Take the initial version number from RC_PROJECTSOURCEVERSION if it
 # exists, otherwise fall back to the version number stored in the source.
-ENVIRONMENT_VERSION="$RC_PROJECTSOURCEVERSION";
+ENVIRONMENT_VERSION="$RC_ProjectSourceVersion";
 PROPOSED_VERSION=${ENVIRONMENT_VERSION:-$FALLBACK_VERSION}
 chomp PROPOSED_VERSION
 
@@ -44,9 +44,9 @@
 mkdir -p "$(dirname "$OUTPUT_FILE")"
 
-# Take the initial version number from RC_PROJECTSOURCEVERSION if it
+# Take the initial version number from RC_ProjectSourceVersion if it
 # exists, otherwise fall back to the version number stored in the source.
_______________________________________________
webkit-changes mailing list
webkit-changes@lists.webkit.org
https://lists.webkit.org/mailman/listinfo/webkit-changes

Reply via email to